@@ -7,7 +7,7 @@ trap "rm -rf /tmp/test-repo$$ /tmp/target$$ /tmp/out$$" 0 12 2 15
 set -e	# So we'll crap out if hack-repo does not exist
 cp -r hack1.repo/ /tmp/test-repo$$
 cd /tmp/test-repo$$
-repotool checkout /tmp/target$$; echo Return code: $? >/tmp/out$$
+${REPOTOOL:-repotool} checkout /tmp/target$$; echo Return code: $? >/tmp/out$$
 cd - >/dev/null
 rm -rf /tmp/target$$/CVS/	# CVS internal use, and contents are different every time
 ./dir-md5 /tmp/target$$  >>/tmp/out$$
