@@ -5,7 +5,7 @@ command -v git >/dev/null 2>&1 || { echo "    Skipped, git missing."; exit 0; }
 trap "rm -rf /tmp/test-repo$$ /tmp/out$$" 0 12 2 15
 
 ./fi-to-fi -n /tmp/test-repo$$ < simple.fi
-(cd /tmp/test-repo$$ >/dev/null; repotool export) | diff --text -u --label simple.fi simple.fi --label repotool-export - >/tmp/out$$
+(cd /tmp/test-repo$$ >/dev/null; ${REPOTOOL:-repotool} export) | diff --text -u --label simple.fi simple.fi --label repotool-export - >/tmp/out$$
 
 case $1 in
     --regress)
